@@ -13,9 +13,6 @@
 from itertools import cycle
 import logging
 import random
-import six
-
-from six.moves import xrange
 
 from .base import Producer
 
@@ -50,13 +47,13 @@ class SimpleProducer(Producer):
             # Randomize the initial partition that is returned
             if self.random_start:
                 num_partitions = len(self.client.get_partition_ids_for_topic(topic))
-                for _ in xrange(random.randint(0, num_partitions - 1)):
+                for _ in range(random.randint(0, num_partitions - 1)):
                     next(self.partition_cycles[topic])
 
         return next(self.partition_cycles[topic])
 
     def send_messages(self, topic, *msg):
-        if not isinstance(topic, six.binary_type):
+        if not isinstance(topic, bytes):
             topic = topic.encode('utf-8')
 
         partition = self._next_partition(topic)
