@@ -13,8 +13,6 @@
 import logging
 import struct
 
-from six.moves import xrange
-
 from monasca_common.kafka_lib.codec import (
     gzip_encode, gzip_decode, snappy_encode, snappy_decode
 )
@@ -516,11 +514,11 @@ class KafkaProtocol(object):
         ((correlation_id,), cur) = relative_unpack('>i', data, 0)
         ((num_topics,), cur) = relative_unpack('>i', data, cur)
 
-        for _ in xrange(num_topics):
+        for _ in range(num_topics):
             (topic, cur) = read_short_string(data, cur)
             ((num_partitions,), cur) = relative_unpack('>i', data, cur)
 
-            for _ in xrange(num_partitions):
+            for _ in range(num_partitions):
                 ((partition, error), cur) = relative_unpack('>ih', data, cur)
                 yield OffsetCommitResponse(topic, partition, error)
 
